@@ -1,7 +1,7 @@
 /*! \file _build.h
  * \brief Build identification and version info.
  *
- * $Id: _build.h 5883 2017-01-01 12:49:00Z sdennis $
+ * $Id: _build.h 5954 2017-08-05 16:36:23Z sdennis $
  *
  */
 
@@ -15,8 +15,8 @@ extern char szBuildDate[];
 #define MUX_BUILD_DATE szBuildDate
 #endif // MUX_BUILD_DATE
 
-#define MUX_VERSION       "2.10.1.13"        // Version number
-#define MUX_RELEASE_DATE  "2017-JAN-01"      // Source release date
+#define MUX_VERSION       "2.10.1.14"        // Version number
+#define MUX_RELEASE_DATE  "2017-AUG-05"      // Source release date
 
 // Define if this release is qualified as ALPHA or BETA.
 //
