@@ -1,7 +1,7 @@
 /*! \file set.cpp
  * \brief Commands which modify objects.
  *
- * $Id: set.cpp 5803 2016-03-10 14:24:06Z sdennis $
+ * $Id: set.cpp 5947 2017-07-15 20:31:42Z sdennis $
  *
  * These functions primarily implement commands like \@set and
  * \@name that modify attributes or basic properties of an object,
@@ -1287,7 +1287,7 @@ void do_set
 
     if (*p)
     {
-        *p++ = 0;
+        *p++ = '\0';
         int atr = mkattr(executor, flagname);
         if (atr <= 0)
         {
@@ -1312,8 +1312,8 @@ void do_set
         {
             p++;
 
-            attr_info src(thing, pattr);
-            attr_info dest(executor, p, false, false);
+            attr_info src(executor, p, false, false);
+            attr_info dest(thing, pattr);
             copy_attr(executor, src, dest, key);
             return;
         }
